import os
import json
from glob import glob
import subprocess

# Set project root and configuration paths
PROJECT_ROOT = os.getcwd()

# Read the JSON configuration file
config_path = os.path.join(PROJECT_ROOT, 'config.json')

if not os.path.exists(config_path):
    raise FileNotFoundError(f"Configuration file not found: {config_path}")

with open(config_path, 'r') as config_file:
    project_config = json.load(config_file)

# Extract project name and Dezyne runtime path from config
PROJECT_NAME = project_config['projectName']
DEZYNE_PATH = project_config['dezynePath']

# Print project information
print(f"Project Name: {PROJECT_NAME}")

###########################################################
## Dezyne Code Generation                                 ##
###########################################################

# List all Dezyne models in the "Models" directory
dezyne_models = glob("Models/*.dzn")

if not dezyne_models:
    print("No Dezyne models found in the 'Models' directory.")


# Simulate code generation from Dezyne models
for model in dezyne_models:
    model_name = os.path.splitext(os.path.basename(model))[0]
    model_py = os.path.join(PROJECT_ROOT, 'dzn', f"{model_name}.py")
    dzn_path = os.path.join(DEZYNE_PATH, 'dzn')
    code_output = os.path.join(PROJECT_ROOT, 'dzn')

    # Check if the model filename contains 'skel' or 'Skel'
    if "skel" in model_name.lower():
        # If the Python file already exists, skip the generation
        if os.path.exists(model_py):
            print(f"Skipping code generation for {model}: {model_py} already exists (skel file).")
            continue  # Skip this iteration

    # Normally, this is where you'd run the Dezyne code generation tool
    print(f"Generating code from {model}")

    # Command to generate Dezyne code
    command = [dzn_path, "code", model, "-l", "python", "-o", code_output]

    # Run the Dezyne code generation command, suppressing stdout and stderr
    try:
        result = subprocess.run(command, check=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        if result.returncode == 0:
            print(f"Successfully generated {model_py} from {model}")
        else:
            print(f"Error generating code for {model}: {result.stderr.decode()}")
    except subprocess.CalledProcessError as e:
        print(f"Error generating code for {model}: {e}")
